@@ -40,10 +40,10 @@ if(sort) { cat("\nItem by Cluster Structure matrix: Sorted by loading \n")
 	    print(fx,quote="FALSE")
  		
  		eigenvalues <- diag(t(x$pattern) %*% x$loadings)
-       cat("\nWith eigenvalues of:\n")
+       cat("\nWith Sums of squares of:\n")
        print(eigenvalues,digits=digits)
  		}
- 	else {
+ 	else {if(is.null(cut)) cut <- 0   #added 8/9/16
 	 cat("\nItem by Cluster Structure matrix:\n")
 	    load <- unclass(x$loadings)
 	    load <- round(load,digits)
@@ -58,7 +58,7 @@ if(sort) { cat("\nItem by Cluster Structure matrix: Sorted by loading \n")
 	    print(clust.fx,quote="FALSE")
  		#print(unclass(x$loadings)) 
  		eigenvalues <- diag(t(x$pattern) %*% x$loadings)
-       cat("\nWith eigenvalues of:\n")
+       cat("\nWith Sums of squares of:\n")
        print(eigenvalues,digits=digits)
  		}
  if(!is.null(x$purified$cor)) {cat("\nPurified scale intercorrelations\n reliabilities on diagonal\n correlations corrected for attenuation above diagonal: \n")
@@ -66,4 +66,4 @@ print(round(x$purified$corrected,digits=digits))  }
 
 cat("\nCluster fit = ",round(x$fit$clusterfit,digits), "  Pattern fit = ",round(x$fit$patternfit,digits), " RMSR = ",round(x$fit$patternrmse,digits), "\n")
 
-   }# end of if ICLUST
\ No newline at end of file
+   }# end of print.psych.ICLUST
\ No newline at end of file
