@@ -63,7 +63,7 @@ bestScales = { cat("\nCall = ")
             print(object$Call)
          cat("\nValidities from raw items and from the correlation matrix\n")
          cat("Number of unique predictors used = ",object$nvars,"\n")
-        print(object$crossV,digits=digits)
+        if(!is.null(object$mean.fit)) {print(object$mean.fit,digits=digits)} else  {print(object$crossV,digits=digits)}
  },
  
  
@@ -246,9 +246,11 @@ esem =  {
 extend = {cat("\n Factor extensions analysis with Call: ")
    print(object$Call)
  	nfactors <- dim(object$loadings)[2]
- 	cat ("\n With factor correlations of \n" )
+ 	if(!is.null(object$Phi)){cat ("\n With factor correlations of \n" )
        colnames(object$Phi) <- rownames(object$Phi) <- colnames(object$loadings)
-       print(round(object$Phi,digits))},
+       print(round(object$Phi,digits))}
+       
+       },
  	
  	
 fa =  {
@@ -288,7 +290,11 @@ faBy = {cat("\nFactor analysis within groups with Call: ")
  
  
  },
-      
+  
+fa.reg = {cat("\nFactor analysis regression Call: ")
+ print(object$Call)
+ summary(object$regression)
+ },  
 
 items= { 
     if(object=="omega") {
@@ -440,3 +446,5 @@ none = {warning("I am sorry, I do not have a summary function for this object")}
 #invisible(result)
    }
   
+
+#
